@@ -44,7 +44,8 @@ class CrtSigV4Auth(BaseSigner):
         # Use utcnow() because that's what gets mocked by tests, but set
         # timezone because CRT assumes naive datetime is local time.
         datetime_now = datetime.datetime.utcnow().replace(
-            tzinfo=datetime.timezone.utc)
+            tzinfo=datetime.timezone.utc
+        )
 
         # Use existing 'X-Amz-Content-SHA256' header if able
         existing_sha256 = self._get_existing_sha256(request)
@@ -54,7 +55,8 @@ class CrtSigV4Auth(BaseSigner):
         credentials_provider = awscrt.auth.AwsCredentialsProvider.new_static(
             access_key_id=self.credentials.access_key,
             secret_access_key=self.credentials.secret_key,
-            session_token=self.credentials.token)
+            session_token=self.credentials.token,
+        )
 
         if self._is_streaming_checksum_payload(request):
             explicit_payload = STREAMING_UNSIGNED_PAYLOAD_TRAILER
@@ -67,8 +69,9 @@ class CrtSigV4Auth(BaseSigner):
             explicit_payload = UNSIGNED_PAYLOAD
 
         if self._should_add_content_sha256_header(explicit_payload):
-            body_header = \
+            body_header = (
                 awscrt.auth.AwsSignedBodyHeaderType.X_AMZ_CONTENT_SHA_256
+            )
         else:
             body_header = awscrt.auth.AwsSignedBodyHeaderType.NONE
 
@@ -98,10 +101,10 @@ class CrtSigV4Auth(BaseSigner):
             array = []
             for (param, value) in aws_request.params.items():
                 value = str(value)
-                array.append('%s=%s' % (param, value))
+                array.append(f'{param}={value}')
             crt_path = crt_path + '?' + '&'.join(array)
         elif url_parts.query:
-            crt_path = '%s?%s' % (crt_path, url_parts.query)
+            crt_path = f'{crt_path}?{url_parts.query}'
 
         crt_headers = awscrt.http.HttpHeaders(aws_request.headers.items())
 
@@ -117,13 +120,15 @@ class CrtSigV4Auth(BaseSigner):
             method=aws_request.method,
             path=crt_path,
             headers=crt_headers,
-            body_stream=crt_body_stream)
+            body_stream=crt_body_stream,
+        )
         return crt_request
 
     def _apply_signing_changes(self, aws_request, signed_crt_request):
         # Apply changes from signed CRT request to the AWSRequest
         aws_request.headers = HTTPHeaders.from_pairs(
-            list(signed_crt_request.headers))
+            list(signed_crt_request.headers)
+        )
 
     def _should_sign_header(self, name, **kwargs):
         return name.lower() not in SIGNED_HEADERS_BLACKLIST
@@ -192,8 +197,10 @@ class CrtS3SigV4Auth(CrtSigV4Auth):
         algorithm = checksum_context.get('request_algorithm')
         if isinstance(algorithm, dict) and algorithm.get('in') == 'header':
             checksum_header = algorithm['name']
-        if not request.url.startswith('https') or \
-                checksum_header not in request.headers:
+        if (
+            not request.url.startswith('https')
+            or checksum_header not in request.headers
+        ):
             return True
 
         # If the input is streaming we disable body signing by default.
@@ -234,7 +241,8 @@ class CrtSigV4AsymAuth(BaseSigner):
         # Use utcnow() because that's what gets mocked by tests, but set
         # timezone because CRT assumes naive datetime is local time.
         datetime_now = datetime.datetime.utcnow().replace(
-            tzinfo=datetime.timezone.utc)
+            tzinfo=datetime.timezone.utc
+        )
 
         # Use existing 'X-Amz-Content-SHA256' header if able
         existing_sha256 = self._get_existing_sha256(request)
@@ -244,7 +252,8 @@ class CrtSigV4AsymAuth(BaseSigner):
         credentials_provider = awscrt.auth.AwsCredentialsProvider.new_static(
             access_key_id=self.credentials.access_key,
             secret_access_key=self.credentials.secret_key,
-            session_token=self.credentials.token)
+            session_token=self.credentials.token,
+        )
 
         if self._is_streaming_checksum_payload(request):
             explicit_payload = STREAMING_UNSIGNED_PAYLOAD_TRAILER
@@ -257,8 +266,9 @@ class CrtSigV4AsymAuth(BaseSigner):
             explicit_payload = UNSIGNED_PAYLOAD
 
         if self._should_add_content_sha256_header(explicit_payload):
-            body_header = \
+            body_header = (
                 awscrt.auth.AwsSignedBodyHeaderType.X_AMZ_CONTENT_SHA_256
+            )
         else:
             body_header = awscrt.auth.AwsSignedBodyHeaderType.NONE
 
@@ -288,10 +298,10 @@ class CrtSigV4AsymAuth(BaseSigner):
             array = []
             for (param, value) in aws_request.params.items():
                 value = str(value)
-                array.append('%s=%s' % (param, value))
+                array.append(f'{param}={value}')
             crt_path = crt_path + '?' + '&'.join(array)
         elif url_parts.query:
-            crt_path = '%s?%s' % (crt_path, url_parts.query)
+            crt_path = f'{crt_path}?{url_parts.query}'
 
         crt_headers = awscrt.http.HttpHeaders(aws_request.headers.items())
 
@@ -307,13 +317,15 @@ class CrtSigV4AsymAuth(BaseSigner):
             method=aws_request.method,
             path=crt_path,
             headers=crt_headers,
-            body_stream=crt_body_stream)
+            body_stream=crt_body_stream,
+        )
         return crt_request
 
     def _apply_signing_changes(self, aws_request, signed_crt_request):
         # Apply changes from signed CRT request to the AWSRequest
         aws_request.headers = HTTPHeaders.from_pairs(
-            list(signed_crt_request.headers))
+            list(signed_crt_request.headers)
+        )
 
     def _should_sign_header(self, name, **kwargs):
         return name.lower() not in SIGNED_HEADERS_BLACKLIST
@@ -382,8 +394,10 @@ class CrtS3SigV4AsymAuth(CrtSigV4AsymAuth):
         # to implicitly disable body signing. The combination of TLS and
         # content-md5 is sufficiently secure and durable for us to be
         # confident in the request without body signing.
-        if not request.url.startswith('https') or \
-                'Content-MD5' not in request.headers:
+        if (
+            not request.url.startswith('https')
+            or 'Content-MD5' not in request.headers
+        ):
             return True
 
         # If the input is streaming we disable body signing by default.
@@ -403,8 +417,9 @@ class CrtSigV4AsymQueryAuth(CrtSigV4AsymAuth):
     DEFAULT_EXPIRES = 3600
     _SIGNATURE_TYPE = awscrt.auth.AwsSignatureType.HTTP_REQUEST_QUERY_PARAMS
 
-    def __init__(self, credentials, service_name, region_name,
-                 expires=DEFAULT_EXPIRES):
+    def __init__(
+        self, credentials, service_name, region_name, expires=DEFAULT_EXPIRES
+    ):
         super().__init__(credentials, service_name, region_name)
         self._expiration_in_seconds = expires
 
@@ -423,9 +438,9 @@ class CrtSigV4AsymQueryAuth(CrtSigV4AsymAuth):
         # parse_qs makes each value a list, but in our case we know we won't
         # have repeated keys so we know we have single element lists which we
         # can convert back to scalar values.
-        query_dict = dict(
-            [(k, v[0]) for k, v in
-             parse_qs(url_parts.query, keep_blank_values=True).items()])
+        query_string_parts = parse_qs(url_parts.query, keep_blank_values=True)
+        query_dict = {k: v[0] for k, v in query_string_parts.items()}
+
         # The spec is particular about this.  It *has* to be:
         # https://<endpoint>?<operation params>&<auth params>
         # You can't mix the two types of params together, i.e just keep doing
@@ -493,8 +508,9 @@ class CrtSigV4QueryAuth(CrtSigV4Auth):
     DEFAULT_EXPIRES = 3600
     _SIGNATURE_TYPE = awscrt.auth.AwsSignatureType.HTTP_REQUEST_QUERY_PARAMS
 
-    def __init__(self, credentials, service_name, region_name,
-                 expires=DEFAULT_EXPIRES):
+    def __init__(
+        self, credentials, service_name, region_name, expires=DEFAULT_EXPIRES
+    ):
         super().__init__(credentials, service_name, region_name)
         self._expiration_in_seconds = expires
 
@@ -513,9 +529,12 @@ class CrtSigV4QueryAuth(CrtSigV4Auth):
         # parse_qs makes each value a list, but in our case we know we won't
         # have repeated keys so we know we have single element lists which we
         # can convert back to scalar values.
-        query_dict = dict(
-            [(k, v[0]) for k, v in
-             parse_qs(url_parts.query, keep_blank_values=True).items()])
+        query_dict = {
+            k: v[0]
+            for k, v in parse_qs(
+                url_parts.query, keep_blank_values=True
+            ).items()
+        }
         if request.params:
             query_dict.update(request.params)
             request.params = {}
@@ -593,5 +612,5 @@ CRT_AUTH_TYPE_MAPS = {
     's3v4': CrtS3SigV4Auth,
     's3v4-query': CrtS3SigV4QueryAuth,
     's3v4a': CrtS3SigV4AsymAuth,
-    's3v4a-query': CrtS3SigV4AsymQueryAuth
+    's3v4a-query': CrtS3SigV4AsymQueryAuth,
 }
